/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2005-02-17
 * Description : a plugin to change image perspective .
 *
 * Copyright (C) 2005-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEPLUGIN_PERSPECTIVE_H
#define IMAGEPLUGIN_PERSPECTIVE_H

// Digikam includes.

#include "imageplugin.h"
#include "digikam_export.h"

class TDEAction;

class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Perspective : public Digikam::ImagePlugin
{
    Q_OBJECT
  

public:

    ImagePlugin_Perspective(TQObject *parent, const char* name,
                            const TQStringList &args);
    ~ImagePlugin_Perspective();

    void setEnabledActions(bool enable);

private slots:

    void slotPerspective();

private:

    TDEAction *m_perspectiveAction;
};

#endif /* IMAGEPLUGIN_PERSPECTIVE_H */
